\name{.GtkCall}
\alias{.GtkCall}
\title{A Gtk-specific .Call()}
\description{
  This is a wrapper for the general \code{\link{.Call}}
  that adds an optional call to \code{\link{gdkFlush}}
  at the end to flush all of the Gdk and Gtk events
  to update the display, etc.
}
\usage{
.GtkCall(name, ..., .flush=TRUE)
}
\arguments{
  \item{name}{the name of the native C routine to call.}
  \item{...}{the arguments to pass to the C routine.
    These can contain the specific named arguments
    for \code{\link{.Call}} such as \code{PACKAGE}
    and \code{DUP}.}
  \item{.flush}{a logical value indicating whether to call
    \code{\link{gdkFlush}} after the \code{\link{.Call}}
   returns.}
}
\details{
}
\value{
 The value returned by the actual call to \code{\link{.Call}}.
}
\references{
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}

\seealso{
 \code{\link[pkg:base]{.Call}}
}

\examples{
}
\keyword{interface}

\eof
\name{gtkSelectionDataSet}
\alias{gtkSelectionDataSet}
\alias{[[.GtkSelectionData}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Fill this in later}
\description{

}
\usage{
gtkSelectionDataSet(data, type, format, value)
"[[.GtkSelectionData"(x, name)
}
\arguments{
  \item{data}{}
  \item{type}{}
  \item{format}{}
  \item{value}{}
  \item{x}{}
  \item{name}{}
}
\details{

}
\value{

}
\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}

\seealso{}
\examples{

}
\keyword{interface}


\eof
\name{names.GtkObject}
\alias{names.GtkObject}
\alias{gtkObjectGetArgInfo}
\title{Access information about properties of a GtkObject}
\description{
  These allow one to discover what ``properties'' or variables
  a Gtk object supports and the details of each property
  such as its type and whether it can be set or only read.
}
\usage{
names.GtkObject(x)
gtkObjectGetArgInfo(obj, parents=TRUE, collapse=FALSE, strip=FALSE)
}
\arguments{
  \item{x}{the Gtk object the names of whose properties are to be queried}
  \item{obj}{the Gtk object for which the property information is to be retrieved}
  \item{parents}{a logical value indicating whether to get the
    properties of the parent classes as well as the specific class of
    the Gtk object \code{obj}. If this is true, we iterate over the
    successive super-classes of \code{obj}.
    }
  \item{collapse}{a logical value indicating whether the information
    about parent classes should be collapsed into a single list (\code{TRUE})
    or maintained as separate elements in a top-level list that allows
    one to determine to which class each property originates.
    The names of a property contains the class for which it is defined.
  }
  \item{strip}{a logical value indicating whether to remove the
    class prefix in the name of the property (\code{TRUE}) or
    leave it (\code{FALSE}) so that one can identify for which class
    the property was defined and inherited.}
}
\details{
  A regular user will probably want to look at
  \code{names} and call \code{gtkObjectGetArgInfo}
  with \code{parents = TRUE}, \code{collapse=TRUE} and \code{strip =
    TRUE} to find all the available properties in the most
  convenient format.
  Tool writers using the reflectance may want to get the associated
  classes and process the properties hierarchically.
}
\value{
  \code{names} returns a character vector giving
  the names of the available properties
  with the class prefix removed.

  \code{gtkObjectGetArgInfo} returns a list giving details of
  the properties. At the lowest level, each property
  is described by a list containing
  \item{type}{an object of class \code{GtkType} which identifies the
   type (!) of the value of the property.}
  \item{flag}{an object of class \code{GtkArgFlags} which
    specifies whether the property is read-only or read-write
    and when it can be specified, etc. This is a 
    logical OR of the relevant values. See \code{\link{.GtkArgFlags}}.}
  Each property is indexed by its name in the list.
  
  The precise form of the returned value depends on the different
  arguments.
  If \code{parents} is \code{FALSE}, then a simple list giving
  each property for the class of \code{obj} is returned.
  If \code{parents} is \code{TRUE} and \code{collapse} is
  \code{FALSE}, then a list indexed by class is returned.
  Each element is a list containing the property information.

  If \code{strip} is \code{FALSE}, the property names used to
  to index the list of properties does not contain the class identifier
  (\code{class:...}). Otherwise it does.
  
}
\references{

}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}
\note{
}


\seealso{
\code{\link{$.GtkObject}}
}

\examples{

}
\keyword{interface}

\eof
\name{gtkCheckInherits}
\alias{gtkCheckInherits}
\title{Verify an object's class}
\description{
  Checks whether the given object extends the appropriate
  class, raising an error if not.
  This is used to validate an object before it is passed
  to C code which expects an object of the appropriate type.
}
\usage{
gtkCheckInherits(w, klass="GtkWidget", nullOk=FALSE, critical=TRUE)
}
\arguments{
  \item{w}{the object whose classes are to be checked to
    determine if it ``extends'' the class \code{klass}.}
  \item{klass}{the class which the object \code{w} is expected
    to extend.}
  \item{nullOk}{a logical value which controls whether
    a value of \code{NULL} for \code{w} is acceptable
    and passes the test. If this is not \code{TRUE},
    a value of \code{NULL} throws an error.}
  \item{critical}{a logical value or a string that controls whether
    an error is raised if the object \code{w} does not inherit from
    \code{klass}.
    If this is a string, it is used as the error message.
    If it is a logical value and is \code{TRUE}, an error is raised.
  }
}
\details{
 This 
}
\value{
 A logical value or an error!
}
\references{
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}
\seealso{
  \code{\link[pkg:base]{inherits}}
  \code{\link[pkg:base]{stop}}
}

\examples{
}
\keyword{interface}


\eof
\name{children}
\alias{gtkChildren}
\alias{gtkContainerGetChildren}
\alias{gtkParent}
\alias{gtkWidgetGetParent}
\title{Get child widgets of a Gtk container}
\description{
This returns a list of the widgets that
are currently contained or managed by 
a particular Gtk container widget.
}
\usage{
gtkChildren(w, full = TRUE)
gtkContainerGetChildren(w, full = TRUE)
gtkParent(w, full = TRUE)
gtkWidgetGetParent(w, full = TRUE)
}
\arguments{
  \item{w}{the Gtk widget object whose children or parent
    widget(s) are to be retrieved.
    For \code{gtkChildren}, the object should be an object
    that inherits from the class \code{GtkContainer}.
  }
  \item{full}{a logical value indicating whether we should
    examine the resulting object(s) and expand the class
    based on the run-time type. If this is \code{FALSE},
    a generic class \code{GtkWidget} is used.
    If one does not need to know what type of widget the
    parent or children widgets are, then specify \code{FALSE}
   to save processing.}
}
\value{
 For \code{gtkChildren},
  a list with each element corresponding
  to a child in the container widget.


  If \code{full} is \code{TRUE}, the class of each widget
  returned will contain information about the actual
  type of the underlying Gtk widget. Otherwise, it will simply
  be \code{GtkWidget}.
  
}
\references{
\url{http://www.gtk.org}
\url{http://www.omegahat.org/RGtk}
}
\author{Duncan Temple Lang}
\note{This is an extra-ordinarily early release 
intended to encourage others to contribute code, etc.}

\seealso{
\code{\link{gtkParent}}
}

\examples{

}
\keyword{interface}
\keyword{GUI}

\eof
\name{.getAutoMethodByName}
\alias{.getAutoMethodByName}
\alias{.getAutoElementByName}
\title{Locates Gtk class methods for an object}
\description{
  These functions are used to
  access Gtk class-specific methods
  using the \code{$} operator,
  as in \code{obj$Add}.
  These look for the method \code{name}
  for each of the classes from which
  \code{obj} inherits.
}
\usage{
.getAutoMethodByName(obj, name, prefix=c("Gtk", "gtk"))
.getAutoElementByName(obj, name, prefix=c("Gtk", "gtk"), error = TRUE)
}

\arguments{
  \item{obj}{the \code{GtkObject} which defines the classes of interest.}
  \item{name}{the name of the method or accessor being sought.}
  \item{prefix}{a vector giving a pair of values mapping the
    class prefix (e.g. Gdk) to the function name
    \code{gtk} prefix. This allows us to handle
    Gtk and Gdk objects.
  }
  \item{error}{a logical value indicating whether to throw an error
    or simply return an object of class \code{try-error} if no
    element is found for the specified name.}
}
\details{

}
\value{

}
\references{

}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}



\seealso{
\code{\link{$.GtkObject}}
}

\examples{

}
\keyword{interface}

\eof
\name{findWidgetByType}
\alias{findWidgetByType}
\title{Find widget in hierarchy by type}
\description{
  This function recursively descends the widget hierarchy
  identified by the root node \code{win} and finds the first
  widget that matches the specified target type.
}
\usage{
findWidgetByType(win, gtkType = "GtkMenuBar", verbose = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{win}{the root node of the widget hierarchy whose children and
    descendants are to be searced.}
  \item{gtkType}{the name of the Gtk type we are looking for.
    If this is a function, it is called for each widget in the hierarchy
    until it returns \code{TRUE}.
    Each call is given the widget as its only argument
    and expected to return a logical value indicating whether the
    widget matches or not. One can use a closure and always
    return \code{FALSE} if one wants to iterate over all the
    widgets and collect the matching ones.
  }
  \item{verbose}{a logical value indicating whether to print information
   to the console as we recurse.}
}

\value{
 The widget that matched or \code{NULL}.
}

\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}


\seealso{
\code{\link{gtkContainerGetChildren}}
}
\examples{

}
\keyword{interface}



\eof
\name{gtkObjectGetSignals}
\alias{gtkObjectGetSignals}
\alias{gtkTypeGetSignals}
\title{Retrieve information about available signals}
\description{
  This provides dynamic (run-time) reflectance information about
  the available signals for a Gtk type/class.
  It gives the names of the signals, the parameters
  for the associated callback function and when it is called
  (i.e. before or after the object calls its own handlers).
}
\usage{
gtkObjectGetSignals(w)
gtkTypeGetSignals(type)
}

\arguments{
  \item{w}{the Gtk object whose signals are to be queried.}
  \item{type}{a string or object of class \code{GtkType} whose signals
    are to be retrieved.}  
}
\details{

}
\value{
}
\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}


\seealso{
\code{\link{gtkAddCallback}}
}

\examples{

}
\keyword{interface}

\eof
\name{getSignalInfo}
\alias{getSignalInfo}
\title{Information for all signals for multiple classes}
\description{
  This retrieves the signal information for
  all of the signals defined for each of the classes
  specified by \code{classes}.
  This is just a convenient front-end to
  \code{\link{gtkSignalGetInfo}} for a large number of signals.
}
\usage{
getSignalInfo(classes=.GtkClasses, load=TRUE)
}
\arguments{
  \item{classes}{a character vector containing the names of
  different Gtk classes/types}
\item{load}{a logical value indicating whether to
  force the initialization of the different classes
  before asking for their signals. The class must be initialized
  for the information to be available. If an instance of the
  class has been created or the C routine \code{gtk_<type>_get_type}
  has been called (directly or indirectly), the class has been initialized.}
}
\value{
  A list with elements for each of the classes.
  Each element is itself a list with an element for
  each of the signals defined for that class.
  Each element within this list is the value returned
  from \code{\link{gtkSignalGetInfo}}
}
\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}


\seealso{
  \code{\link{gtkSignalGetInfo}}
}

\examples{
 gtkInit()
 .C("gtk_button_get_type", PACKAGE = "RGtk")
 getSignalInfo("GtkButton")
}
\keyword{interface}

\eof
\name{gtkGetType}
\alias{gtkGetType}
\alias{gtkObjectGetType}
\title{Get the GtkType object from a Gtk object or name}
\description{
  This retrieves the \code{GtkType} object  for a given
  \code{GtkObject} or directly by name.
  This can be used to dynamically discover information
  about a Gtk class such as its signals, properties,
  inheritance hierarchy, etc.
}
\usage{
gtkGetType(name)
gtkObjectGetType(w, check=TRUE)
}
\arguments{
  \item{name}{a character vector giving the name of the Gtk class/type
    to be retrieved.}
  \item{w}{a GtkObject whose type is to be queried and returned.}
  \item{check}{a logical value indicating whether we should first verify
    that the \code{w} object inherits from GtkObject.
    Typically one passes \code{TRUE} for this. It is useful
    when one gets an incomplete object constructed directly in C code
    and we want to construct its class information
    (\code{gtkObjectGetClasses}) manually.   }
}
\details{
  If one calls \code{gtkGetType} with a string
  giving the name of the Gtk class, the associated
  Gtk class must have been initialized first.
  Specifically an object of that class
  must have been created earlier or
  the associated \code{gtk_<class>_get_type}
  called.
  This can be done using the \code{\link[base]{.C}}
  function as in \code{.C("gtk_button_get_type", PACKAGE= "RGtk")}.
  
  
}
\value{
  A single real value giving the internal
  C-level identifier for the Gtk type value.
  The name of the type is used as the \code{names}
  vector for the numeric vector.
}
\references{

}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}
\note{

}

\seealso{
  \code{\link{gtkObjectGetClasses}}
  \code{\link{gtkTypeGetClasses}}  
}

\examples{

}
\keyword{interface}

\eof
\name{gtkAdd}
\alias{gtkAdd}
\title{Add Gtk wdget to parent container}
\description{
This adds the specified Gtk widget
to the hierarchy defining a graphical
interface by giving it a parent
and a place in the parent's container.
This is then followed by a call to
\code{\link{gtkShow}} to make the
widget visible.
}
\usage{
gtkAdd(parent, ..., .flush = TRUE)
}
\arguments{
  \item{parent}{the parent container widget (e.g. a box, etc. )
    into which the widget `w' is to be added.}
  \item{...}{one or more widgets that are to be added to the parent
    container.}
 \item{.flush}{a logical value indicating whether to flush
   the event queue to encourage any changes to be processed
   immediately.}  
}

\value{
Currently, a logical value indicating whether
the, typically a logical value, \code{TRUE},
indicating success.
This will be changed to be a widget.
Perhaps we will add an option to allow a scrolled
container or a pane to be added in which case the
result will be that newly created container widget.
}
\references{
\url{http://www.gtk.org}
\url{http://www.omegahat.org/RGtk}
}
\author{Duncan Temple Lang}

\seealso{
 \code{\link{gtkContainerAdd}}
 \code{\link{gtkWindow}}
 \code{\link{gtkShow}}
}

\examples{

}
\keyword{interface}
\keyword{GUI}


\eof
\name{gtkAddCallback}
\alias{gtkAddCallback}
\alias{gtkObjectAddCallback}
\alias{gtkObjectBlockCallback}
\alias{gtkObjectUnblockCallback}
\alias{gtkObjectDisconnectCallback}
\alias{gtkObjectRemoveCallback}
\title{Register and control a function as Gtk event handler}
\description{
  These functions allow one to register an R expression,
   call or more typically a function as a
  callback for a Gtk event, and also control
  the activity status of that callback.
\code{gtkObjectAddCallback} registers the S expression, call or function
as a callback or event handler
for the specific event type
with the widget of interest.
When the event occurs for this widget, 
the S "expression" will be invoked.

The block and unblock functions allow one to temporarily
suspend and re-enable a callback. When suspended, any calls
to the function that would normally occur are not invoked.

\code{gtkObjectRemoveCallback} allows one to unregister a callback using
the identifier obtained when call \code{gtkObjectAddCallback}.

\code{gtkObjectDisconnectCallback} un-registers a callback.
}
\usage{
gtkObjectAddCallback(w, signal, f, data = NULL, object = TRUE, after = TRUE)
gtkAddCallback(w, signal, f, data = NULL, object = TRUE, after = TRUE)
gtkObjectBlockCallback(obj, id)
gtkObjectUnblockCallback(obj, id)
gtkObjectDisconnectCallback(obj, id)
}
\arguments{
  \item{w}{the Gtk object whose events for this signal type
      are to be monitored and reported to us via a call to the function \code{f}.}
  \item{signal}{a string (character vector of length 1) giving
  the name of the signal type. See the Gtk documentation for the 
  particular widget.}
  \item{obj}{the Gtk object for which we want to block/unblock or
    disconnect the callback.}
  \item{f}{the S expression, call or function which is to be invoked when an event
    occurs.
    If this is a call or expression, it is simply evaluated and no
    additional
    variables (i.e. the Gtk object for which the signal was emitted,
    etc.)
    are made available to it.
    If the callback is a function,
    it will be called with a single argument
 which is an external pointer to the C-level event object
 that describes the event.}
  \item{data}{a value that is passed to the function \code{f} when the callback
    is invoked. This can be use to parameterize a callback function so that it
    behaves differently. This is passed as the first argument
    to the function if \code{object} is \code{TRUE}
    or as the final argument if \code{object} is \code{FALSE}.
    If \code{f} is an expression or a call, \code{data} can be
    an environment. In this case, \code{f} is evaluated within
    this environment. This allows the code registering the callback
    to control the scope of the evaluation.
  }
  \item{object}{ a  logical value indicating whether
    we want the value given in the \code{data} argument
    to be the first argument to the callback function and the
    Gtk object for which the event occurs to be the last argument,
    or vice-versa. This is sometimes convenient and is the difference
    between a call to \code{gtk_signal_connect} and
    \code{gtk_signal_connect_object} at the Gtk interface level.
    This argument is only meaningful if \code{data} is not missing
    as no data argument is passed to the callback if it is not supplied.
  }
  \item{after}{a logical value indicating whether 
    to invoke this user-defined handler after the signal, or to let the
    signal's default behavior preside (i.e. depending on GTK_RUN_FIRST
    and GTK_RUN_LAST).
    This influences which signal gets to return a value to the event
    source which can be useful. If the return value is \code{void},
    this rarely matters and one can accept the default.
  }
  \item{id}{}
}
\details{
 The S function is invoked by a generic C-level event 
 handler that makes the call to the S function. That
 function is stored in user-level data for the widget.
 The call provides one argument which is a reference to the
 C event instance.
}
\value{
  \code{gtkObjectAddCallback} returns an object of class
  \code{CallbackID} that provides a unique identifier
  for the Gtk-level handler.
  This is an integer value whose name attribute gives the name of the signal.
  This object can be used to suspend (block), remove (disconnect)
  and reactivate (unblock) a callback.

  The other functions return a logical value indicating if they were
  succesful or else result in an error.
}

\references{
\url{http://www.gtk.org}
\url{http://www.omegahat.org/RGtk}
}
\author{Duncan Temple Lang}
\note{This is an extra-ordinarily early release 
intended to encourage others to contribute code, etc.}

\seealso{
\code{\link{gtkButton}}
}

\examples{
 gtkInit()
 w <- gtkWindow(show = FALSE)  
 b <- gtkButton("Hit me")
 w$Add(b)

 gtkShow(w)
 gtkAddCallback(b, "clicked", function(w) {
                                 help.start();
                                 TRUE})
}
\keyword{interface}
\keyword{GUI}

\eof
\name{gtkComboSetPopdownStrings}
\alias{gtkComboSetPopdownStrings}
\title{Interface to Gtk routine.}
\description{
  This is an interface to the \code{gtk_combo_set_popdown_strings}
  routine in the Gtk library.
}
\usage{
gtkComboSetPopdownStrings(combo, strings, .flush = TRUE)
}
\arguments{
  \item{combo}{the GtkCombo object}
  \item{strings}{a character vector giving the strings to use for the
    popdown menu entries.}
  \item{.flush}{a logical value indicating whether to flush the Gtk
    event loop after the call.
   }
}

\value{
 \code{NULL}.
}
\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}

\seealso{
 \code{\link{gtkComboNew}}
}
\examples{

}
\keyword{interface}



\eof
\name{gtkDragSourceSet}
\alias{gtkDragSourceSet}
\alias{gtkDragDestSet}
\title{Set a widget as a potential drop source or destination.}
\description{
 These establish a widget as a drag and drop source or destination.
}
\usage{
gtkDragSourceSet(widget, flags, targets, actions)
gtkDragDestSet(widget, flags, targets, actions)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{widget}{the widget}
  \item{flags}{the flags that specify what actions GTK+ should take on
behalf of a widget for drops onto that widget. The targets and actions
fields only are used if \code{GTK\_DEST\_DEFAULT\_MOTION} or
\code{GTK\_DEST\_DEFAULT\_DROP}
are given.}
  \item{targets}{a pointer to an array of GtkTargetEntry indicating the drop types that this widget will accept.}
  \item{actions}{a bitmask of possible actions for a drop onto this widget.}
}
\details{

}
\value{

}
\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}

\seealso{
  See the Gtk tutorial and API documents
 at \url{http://developer.gnome.org/doc/API/gtk/gtk-drag-and-drop.html}}
\examples{

}
\keyword{interface}


\eof
\name{gtdFlush}
\alias{gdkFlush}
\title{Flush Gtk events}
\description{
This is a simple call to ensure that events
that actions that affect widgets, etc.
are sent to the server and made available
to the R event loop.
This helps to update displays, etc.
}
\usage{
gdkFlush()
}
\value{
}
\references{
\url{http://www.gtk.org}
\url{http://www.omegahat.org/RGtk}
}
\author{Duncan Temple Lang}
\note{Many of the Gtk/Gdk functions
  have a \code{.flush} argument which, if \code{TRUE}, has
  the same effect as calling \code{gdkFlush}
  after that function is called.}

\seealso{
\code{\link{gtkAdd}}
\code{\link{gtkShow}}
}

\examples{
 gdkFlush()

   # create new widget
 w <- gtkWindow(show = FALSE)
 b <- gtkButton("A button")

 w$Add(b)
 gtkShow(w)
 gdkFlush()
   
}
\keyword{interface}
\keyword{GUI}

\eof
\name{gtkGetText}
\alias{gtkTextGetText}
\alias{gtkTextSetText}
\alias{gtkTextClearText}
\title{Access contents of Gtk text widget}
\description{
These functions allow
one to retrieve or set the contents
of a Gtk text widget.
}
\usage{
gtkTextSetText(w, contents="", append = FALSE)
gtkTextGetText(w)
gtkTextClearText(w, start=0, end=-1)
}
\arguments{
  \item{w}{the GtkTextWidget whose contents are to be accessed}
  \item{contents}{a character vector (of length 1) giving the 
   contents to be either appended or inserted into the text widget.}
  \item{append}{a logical value indicating whether the
   new text is to be appended to the existing contents or 
   used to replace it. If this is \code{FALSE}, the text widget
   is currently cleared first.}
  \item{start}{locations in the text widget where the 
   to start clearing the text. These are essentially character offsets
  into the string at present.}
  \item{end}{locations in the text widget where the 
   to complete clearing the text. These are essentially character offsets
  into the string at present.}
}

\value{

}
\references{
\url{http://www.gtk.org}
\url{http://www.omegahat.org/RGtk}
}
\author{Duncan Temple Lang}
\note{This is an extra-ordinarily early release 
intended to encourage others to contribute code, etc.}

\seealso{ }

\examples{

}
\keyword{interface}
\keyword{GUI}


\eof
\name{gtkInit}
\alias{gtkInit}
\title{One-time initialization of Gtk environment}
\description{
This ensures that the Gtk libraries have been 
correctly initialized and can be used to create
widgets, etc.
One can specify arguments to customize how the initialization
is performed, passing Gtk-specific flags to activate
different features.
}
\usage{
gtkInit(args=c("R"))
}
\arguments{
  \item{args}{a character vector of ``command line'' arguments
 used to initialize the Gtk libraries. See the Gtk documentation
  for valid arguments.}
}
\details{

}
\value{

}
\references{
\url{http://www.gtk.org}
\url{http://www.omegahat.org/RGtk}
}
\author{Duncan Temple Lang}


\examples{

}
\keyword{interface}
\keyword{GUI}

\eof
\name{gtkObjectRef}
\alias{gtkObjectRef}
\alias{gtkObjectUnref}
\title{Increment and decrement GtkObject references}
\description{
  This allows the R programmer to explicitly
  increment and decrement the references to a GtkObject.
  This is useful, indeed necessary, if one needs to ensure
  that a particular GtkObject needs to exist even if
  it would be garbage collected by Gtk's own reference
  mechanism. For example, if we remove a GtkWidget from
  a GUI but want to use it later, we should increase
  the reference count by 1 before removing it
  and decrement it after we have added it to the
  new GUI.
}
\usage{
gtkObjectRef(obj)
gtkObjectUnref(obj)
}
\arguments{
  \item{obj}{the GtkObject whose reference count is to be altered.}
}
\details{
  These functions are direct interfaces to the
  \code{gtk_object_ref} and \code{gtk_object_unref}
  routines in the Gtk library.
}
\value{

}
\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}

\seealso{
\code{\link{gtkContainerRemove}}
}
\examples{
\dontrun{
 win = gtkWindow()
 b1 = gtkButton("A button")
 b2 = gtkButton("Another button")

 b1$Ref()
 b2$Ref()

 b1$AddCallback("clicked",
                   function(b, w)  {
                      win$Remove(w)
                      win$Add(b)
                   }, b2)
 b2$AddCallback("clicked",
                   function(b, w)  {
                      win$Remove(w)
                      win$Add(b)
                   }, b1)


 win$AddCallback("destroy",
                  function(obj) {
                    b1$Unref()
                    b2$Unref()
                  })
} 
}
\keyword{interface}


\eof
\name{gtkObjectSignalEmit}
\alias{gtkObjectSignalEmit}
\title{Emit a Gtk signal from a Gtk object.}
\description{
  This allows us to emit or raise a Gtk signal
  from a Gtk object directly from R.
  This should not be used widely. The conversion
  of the arguments to their C equivalents is
  complex.
}
\usage{
gtkObjectSignalEmit(obj, signal, ..., .flush = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{obj}{the GtkObject from which the event is to be emitted.}
  \item{signal}{the identifier of the signal/event, typically a string
    giving the name of the event.}
  \item{\dots}{the arguments that are passed in the signal emission to
    the callbacks/signal handlers.}
  \item{.flush}{a logical value indicating whether to flush the Gdk/Gtk
    event loop.}
}
\details{
  One should not rely on this, and fortunately
  one rarely needs to when developing regular
  GUIs in R. Typically, we only need this when
  we are developing Gtk classes.
}
\value{

}
\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}

\seealso{
 \code{\link{gtkObjectAddCallback}}
}
\examples{

}
\keyword{programming}
\keyword{interface}



\eof
\name{gtkShow}
\alias{gtkShow}
\title{Show/realize one or more Widgets}
\description{
This causes each widget given in the call
to be realized or actually displayed 
}
\usage{
gtkShow(..., all = T, .flush = TRUE)
}

\arguments{
  \item{\dots}{any collection of widgets
   that are to be realized. These are processed
   in the order they are given.}
 \item{all}{a logical value indicating whether to show
   the particular widget (\code{FALSE}), or both
   it and all of the sub-widgets
   which it contains (\code{TRUE}). This is the difference between
   a call to \code{gtk_widget_show} and \code{gtk_widget_show_all}
   in the lower-level Gtk interface. }
 \item{.flush}{a logical value indicating whether to flush
   the event queue to encourage any changes to be processed
   immediately.}
}
\details{
  This calls \code{gtk_widget_show} or
  \code{gtk_widget_show_all} for each widget.
}
\value{
An integer giving the number of widgets
that were realized in the call.
}
\references{
\url{http://www.gtk.org}
\url{http://www.omegahat.org/RGtk}
}
\author{Duncan Temple Lang}

\seealso{
\code{\link{gtkWidgetShow}}
}

\examples{
 gtkInit()
 w <- gtkWindow(show = FALSE) 
 b <- gtkButton("Hit me") # automatically shown in the creation.
 w$Add(b)

 gtkShow(w)
}
\keyword{interface}
\keyword{GUI}

\eof
\name{gtkTargetEntry}
\alias{gtkTargetEntry}
\alias{gtkTargetEntryNew}
\title{Create a new target for drag-n-drop(?)}
\description{
  This creates a new GtkTarget object.
  This is used in transferring data
  in the form of selections
  between processes or widgets.
}
\usage{
gtkTargetEntry(target, flags, info)
gtkTargetEntryNew(target, flags, info)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{target}{a string}
  \item{flags}{an integer value}
  \item{info}{an integer value}
}
\details{
  This allocates a new GtkTargetEntry object in C
  and fills in the targer, flags and info fields.
}
\value{
  A reference to the newly creatd GtkTargetEntry.
}
\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}

\seealso{}
\examples{

}
\keyword{interface}



\eof
\name{gtkTopWindow}
\alias{gtkTopWindow}
\title{Create a Gtk Window}
\description{
  This creates a top-level Gtk window
  (as opposed to a dialog or popup window).
  This is a convenience function for the more
  general \code{\link{gtkWindow}} function
  which is just as easy to use, given its defaults.
}
\usage{
gtkTopWindow(title="My Window", show=TRUE)
}

\arguments{
  \item{title}{a string to use in the title bar for the window.}
  \item{show}{a logical value indicating whether the window should
    be displayed (\code{TRUE}) or left unshown so that other
    widgets can be added to it and then shown.}
}

\value{
  An object of class \code{GtkWindow}
  that has the same inheritance as the low-level
  inheritance in Gtk.
}
\references{
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}
\note{
}

\seealso{
  \code{\link{gtkWindow}}
  \code{\link{gtkWindowNew}}  
}

\examples{

}
\keyword{interface}

\eof
\name{gtkWidgetGetFlags}
\alias{gtkWidgetGetFlags}
\alias{gtkWidgetSetFlags}
\title{Set and get GtkWidget flag values.}
\description{
  These functions allow one to set and retrieve
  values for GtkWidget flags.
}
\usage{
gtkWidgetGetFlags(w)
gtkWidgetSetFlags(w, val, flags = .GtkWidgetFlags) 
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{w}{the widget}
  \item{val}{}
  \item{flags}{}
}
\details{

}
\value{

}

\seealso{}
\examples{

}
\keyword{interface}



\eof
\name{idle}
\alias{gtkAddIdle}
\alias{gtkRemoveIdle}
\title{Control a background/idle function}
\description{
  These functions allow one to register and
  remove a function that is called whenever
  Gtk has nothing else to do. In other words,
  these are background tasks that have less priority
  than timers and user interface events.
}
\usage{
gtkAddIdle(f, data=NULL, .flush=TRUE)
gtkRemoveIdle(id)
}
\arguments{
  \item{f}{ the function should take one or zero arguments
    depending on whether the argument \code{data} is given.
    The function should return a logical value.
    If it returns \code{FALSE}, the timer is removed.
    If it returns \code{TRUE}, the timer  is re-registered and will be called
    after \code{interval} milliseconds.
    }
    \item{data}{a value, which if specified, will be passed to the
      function \code{f} when it is invoked. This can be used to
      parameterize the function to have different functions.
      The same effect can be obtained using closures.
     }
  \item{.flush}{a logical value indicating whether to call
    \code{gdkFlush} or not so as to force the processing of Gtk events.}
  \item{id}{the object identifying the idle function in Gtk
      that was returned by a call to \code{gtkAddTimeout}.}
}
\value{
  \code{gtkAddTimeout} returns an object
  of class \code{"GtkIdleId"}.
  This is an integer giving the identifier
  returned by the low-level Gtk interface.
}
\references{
}

\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}
\note{
  This does not currently work when running directly
  in R. However, when running R inside another application
  such as GGobi, Gnumeric, etc. it and other event-loop
  facilities will work.
}

\seealso{
  \code{\link{gtkAddTimeout}}
  \code{\link{gtkRemoveTimeout}}
  \code{\link{gtkAddCallback}}
}

\examples{
}
\keyword{interface}

\eof
\name{gtkObjectGetArgs}
\alias{gtkObjectGetArgs}
\alias{gtkObjectGetArg}
\alias{[.GtkObject}
\alias{gtkObjectSetArgs}
\alias{[[<-.GtkObject}
\title{Access properties of a Gtk object}
\description{
  These functions allow one to both read
  and set properties of a Gtk object by
  name and also in the usual S-like manner.
  \code{gtkObjectGetArgs} retrieves
  the values of one or more properties by
  specifying their name as a vector.
  \code{gtkObjectGetArg} retrieves the value of a single
  property and avoids having to worry about whether the result
  is a value or a list of values of length 1.
  \code{gtkObjectSetArgs} allows one to set
  one or more properties by name in the form
  \code{gtkObjectSetArgs(obj, x=1, y="a")}.
  \code{[.GtkObject} and \code{[[<-.GtkObject}
  provide S-like accessors.
}
\usage{
gtkObjectGetArgs(obj, argNames)
gtkObjectGetArg(obj, argName)
[.GtkObject(x, ...)
gtkObjectSetArgs(obj, ..., .vals, .flush=TRUE)
[[<-.GtkObject(x, name, value)
}
\arguments{
  \item{obj}{the Gtk object whose properties are to be accessed}
  \item{argNames}{a character vector giving the names of the properties
   to retrieve.}
  \item{argName}{a string (i.e. character vector of length 1)
    giving the name of the property whose value is to be retrieved.}
  \item{x}{the Gtk object whose properties are to be accessed}
  \item{...}{for \code{[.GtkObject}, this is a character vector
   giving the names of the properties of interest.
   For \code{gtkObjectSetArgs}, this is a collection of name=value
   pairs where \code{name} is the name of the property to set and
   \code{value} is the value to which it is to be set.}
  \item{.vals}{a named list similar to \code{...} in \code{gtkObjectSetArgs}
     }
  \item{.flush}{a logical value indicating whether to flush
   the event queue to encourage any changes to be processed
   immediately.}
  \item{name}{the name of the property to set}
  \item{value}{the value to assign to the property}
}
\details{

}
\value{

}
\references{

}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}
\note{

}


\seealso{}

\examples{

}
\keyword{interface}

\eof
\name{[[.GtkObject}
\alias{[[.GtkObject}
\alias{[[.GdkEvent}
\title{Access a value within a Gtk object}
\description{
  These methods allow one to treat Gtk objects
  in an S-like manner and access certain properties
  or values within an object by name
  or accesses the children by index.
  The search works first by looking for an accessor method
  for the Gtk object.
  If no accessor is found, we look for a property or Gtk `argument'
  within the object. If such a named property exists, we retrieve
  its value.
  If the index (\code{name}) is a numeric value, we assume that
  the user means to access the child widget 
  corresponding to that index.
}
\usage{
[[.GtkObject(obj, name)
[[.GdkEvent(obj, name)
}
\arguments{
  \item{obj}{the object in which the value is to be found.}
  \item{name}{the name of the element to retrieve.}
}
\details{
}
\value{
 An S object giving the value
 returned from invoking the accessor function
 or retrieving the named property
 or a GtkWidget  object which is the corresponding child
 of the container widget.
}
\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}

\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}

\seealso{
\code{\link{$.GtkObject}}
\code{\link{.getAutoElementByName}}
\code{\link{.getAutoMethodByName}}
\code{\link{names.GtkObject}}
}

\examples{
 gtkInit()

 dlg <- gtkColorSelectionDialog("", show = FALSE)
  # invoke gtkColorSelectionDialogGetMainVbox()
 dlg[["MainVbox"]]


 b <- gtkButton("My own button")
  # Access a named property/argument.
 b[["label"]]

  # Create a vertical box and put the button into it.
 box <- gtkVBox(TRUE, 2)
 box$PackStart(b)
  # Now get the parent of the button, uses the named
  # property.
 b[["parent"]]

  # Get the first child, indexing by numerical value/position.
 box[[1]]
 
}
\keyword{interface}

\eof
\name{dollar.GtkObject}
\alias{$.GtkObject}
\alias{$.GtkType}
\alias{$.GdkEvent}
\title{Find methods for an S-Gtk object}
\description{
  These accessor functions find the
  appropriate method for a Gtk object
  based on its class hierarchy information.
  This allows one to invoke a method
  such as \code{show}
  on a Gtk object without having to remember
  for which parent class it was defined
  (e.g. GtkWidget).
  So \code{w$Show} will find the method.
  The function exploits the naming convention
  used in Gtk and the R-Gtk interface
  to find S functions of the form
  \code{gtk<Type>FunctionName},
  and it searches for the most appropriate
  function given the object's class.
}
\usage{
obj$name
"$.GtkObject"(obj, name)
"$.GtkType"(obj, name)
"$.GdkEvent"(obj, name)
}
\arguments{
  \item{obj}{the GtkObject whose classes are to be used to find the
    method of interest.}
  \item{name}{the shortened name of the method of interest.
    This is combined with the appropriate class of Gtk object
    to produce the full name.}
}
\details{
  This searches for an appropriate S function by
  combining the name of the function
  with each of the elements in the class
  vector of \code{obj}.
  This can be expensive. A more classical
  OOP mechanism would be more efficient
  and will likely be implemented in the future.
}
\value{
  The return value is a function
  which has access to the \code{obj}
  value so that it can call the real S function
  with that object as the first argument.
  One typically invokes the function
  directly, as in
  \code{w$Show()}
  and it is not intended that one assigns the
  result of the \code{$} operation for later use.
}
\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}
\note{
  In the future, the RGtk interface may use a
  more traditional object oriented class mechanism
  provided by the \url{http://www.omegahat.org/OOP}
  in which case the dispatching will be done
  internally from the definitions of the Gtk class
  rather than using this ``home-made'' mechanism.
}


\seealso{
  \code{\link{[[.GtkObject}}
  \code{\link{.getAutoMethodByName}}
  \code{\link{.getAutoElementByName}}
}

\examples{
 gtkInit()

 w <- gtkButton("My button", show = FALSE)
 w$Show()
 w$Hide()
 w$Destroy()
}
\keyword{interface}

\eof
\name{print.GtkType}
\alias{print.GtkType}
\title{Produce prettier output for a GtkType object}
\description{
  This is a simple method for creating a
  more human-readable view of a \code{GtkType}
  object which represents the underlying
  ``class'' in the C-level Gtk libraries.
  The simplified representation just gives the
  name of the Gtk class (as defined in the C code
  that declares that class).
}
\usage{
print.GtkType(x, ...)
}
\arguments{
  \item{x}{the \code{GtkType} object to be shown.}
  \item{...}{passed on to the \code{print} call for the names.}
}
\details{
  This discards the low-level key used to identify
  the C-level type information and shows ony the
  name of the Gtk type.
}
\value{
 A character vector giving the button.
}
\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}


\seealso{
  \code{\link{gtkGetType}}
  \code{\link{gtkObjectGetType}}  
}

\examples{
 gtkInit()

  # Make certain the class is available to us.
  # Either create an instance or
  #  call the C routine to get the type.
  # .C("gtk_button_get_type")
 gtkButton()

 tp <- gtkGetType("GtkButton")
 print(tp)
}
\keyword{interface}

\eof
\name{gtkSignalGetInfo}
\alias{gtkSignalGetInfo}
\title{Reflectance information about a Gtk signal}
\description{
  This returns information about the
  Gtk signal of interest, giving details
  such as the number and type of parameters that
  are passed to a signal handler function registered
  for an event associated with this signal;
  the type of the return value expected from the handler;
  the class for which it is defined;
  the flags indicating how and when handlers for this signal are invoked when an event occurs;
}
\usage{
gtkSignalGetInfo(sig)
}
\arguments{
  \item{sig}{an object of class \code{GtkSignalId},
   typically obtained from a call to \code{\link{gtkTypeGetSignals}}}
}
\details{
  This uses the C-level reflectance mechanism provided by Gtk
  to obtain information about a particular signal registered
  via the class mechanism. This information is then converted
  to an S object.
}
\value{
  A list with 6 elements
  \item{signal}{the \code{GtkSignalId} object (\code{sig}) used to identify the signal
   in the call}
 \item{parameters}{a named list of parameter types that
   are passed to a callback/signal handler for this signal.
   Each element is a \code{GtkType} object identifying the particular
   type of that argument. The names are intended to give some indication
   of their meaning.
   Note that this list does not include the object for which the event
   is generated and which is included in all signal handler calls.}
 \item{returnType}{the \code{GtkType} object identifying
     the type of the value a handler should return.}
   \item{isUserSignal}{a logical value indicating whether this is
     a user-defined signal or built-in signal}
   \item{runFlags}{a value giving information about how and when
     the handlers are invoked in response to this signal.
     This is a single value made up of OR'ing values from
     the \code{.GtkSignalRunType} vector. See the possible
     values there. One rarely needs to understand this information to
     use a signal handler function.
     }
  \item{objectType}{an object of class \code{GtkType}
    identifying the Gtk class/type for which the signal
     is defined.}
}
\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}

\seealso{
   \code{\link{gtkTypeGetSignals}}
   \code{\link{getSignalInfo}}   
}

\examples{
  # initialization
 gtkInit()
 gtkButton()

 sigs <- gtkTypeGetSignals("GtkButton")
 gtkSignalGetInfo(sigs[["clicked"]])
}

\keyword{interface}

\eof
\name{gtkAddTimeout}
\alias{gtkAddTimeout}
\alias{gtkRemoveTimeout}
\title{Control a periodic/timer function}
\description{
  These functions allow one to register and
  remove a function that is called periodically
  at a fixed interval.
}
\usage{
gtkAddTimeout(interval, f, data=NULL, .flush=TRUE)
gtkRemoveTimeout(id)
}
\arguments{
  \item{interval}{ the number of milliseconds to wait
    before invoking the call.}
  \item{f}{ the function should take one or zero arguments
    depending on whether the argument \code{data} is given.
    The function should return a logical value.
    If it returns \code{FALSE}, the timer is removed.
    If it returns \code{TRUE}, the timer  is re-registered and will be called
    after \code{interval} milliseconds.
    }
    \item{data}{a value, which if specified, will be passed to the
      function \code{f} when it is invoked. This can be used to
      parameterize the function to have different functions.
      The same effect can be obtained using closures.
     }
  \item{.flush}{a logical value indicating whether to call
    \code{gdkFlush} or not so as to force the processing of Gtk events.}
  \item{id}{the object identifying the timer function in Gtk
      that was returned by a call to \code{gtkAddTimeout}.}
}
\value{
  \code{gtkAddTimeout} returns an object
  of class \code{"GtkTimeoutId"}.
  This is an integer giving the identifier
  returned by the low-level Gtk interface.
}
\references{
}

\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}
\note{
  This does not currently work when running directly
  in R. However, when running R inside another application
  such as GGobi, Gnumeric, etc. it and other event-loop
  facilities will work.

  If one wanted to reset the timeout but with a different
  interval, one should register a new timeout within the
  function and return \code{FALSE}.
}

\seealso{
  \code{\link{gtkAddIdle}}
  \code{\link{gtkRemoveIdle}}
  \code{\link{gtkAddCallback}}
}

\examples{
}
\keyword{interface}

\eof
\name{gtkObjectGetClasses}
\alias{gtkObjectGetClasses}
\alias{gtkTypeGetClasses}
\alias{gtkObjectGetTypeName}
\title{Dynamically Computes class information}
\description{
  These functions dynamically compute information
  about the class hierarchy for a given Gtk object
  or a type.
  The class hierarchy is defined by the C-level Gtk
  code and is ``reflected'' to S via these functions.
  Most S-level Gtk objects will be created in the RGtk package
  with the appropriate class. In cases where this is not true,
  \code{gtkObjectGetClass} can be used to compute and assign the
  appropriate class
  so that the regular S interface for that object will work.
}
\usage{
gtkObjectGetClasses(w, check=TRUE)
gtkObjectGetTypeName(w)
gtkTypeGetClasses(type)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{w}{the Gtk object whose class information is to be computed.}
  \item{type}{an S object identifying the Gtk type of interest.
    This can be either a character string giving the name of the
    type or an object of class \code{GtkType}}
  \item{check}{a logical value that can be used to bypass
    a check that the argument \code{w} is of class
    \code{GtkObject}. If the object has not class information
    but the caller knows that it is a pointer to a Gtk object,
    then to compute the class conveniently, \code{check}
    can be passed as \code{FALSE}.}
}
\details{
  This uses C code to query the internal Gtk class hierarchy.
  The class information is not (only) S class information,
  but mirrors the real Gtk class hieararchy.
}
\value{
  A character vector.
  \code{gtkObjectGetTypeName} returns the name of the class/type
  of the given object.
  \code{gtkObjectGetClasses} and \code{gtkTypeGetClasses}
  return the names of the object class/type and its
  successive parent classes, up to  \code{GtkObject}.
}
\references{
  Information on the package is available
  from \url{http://www.omegahat.org/RGtk}.

  Information on Gtk is available from
  \url{http://www.gtk.org}.
}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}
\note{
  Type information about a particular class is not available
  until that class has been initialized.
  One can call the C routine
  \code{gtk_<type-name>_get_type} to initialize it
  or, more commonly and completely, create an instance
  of that class.
  So \code{.C("gtk_button_get_type", PACKAGE = "RGtk")}
  or
  \code{gtkButton()}
  should preceed
  \code{gtkTypeGetClasses("GtkButton")}
}

\seealso{
  \code{\link{gtkObjectGetSignals}}
  \code{\link{gtkTypeGetSignals}}
}

\examples{
  b <- gtkButton()
  class(b)

   # Should be true, but computed in different ways
   # and at different times.
   # class(b) is computed when the RGtk package was generated.
   # gtkObjectGetClasses() is computed at run-time.
  class(b) == gtkObjectGetClasses(b)

}
\keyword{interface}


\eof
\name{gdkGetWindowSize}
\alias{gdkGetWindowSize}
\title{Obtain dimensions of a Gtk window}
\description{
 Returns the width and height of a Gtk window.
}
\usage{
gdkGetWindowSize(w)
}
\arguments{
  \item{w}{the object of class \code{"GdkWindow"}
           whose dimensions are to be queried.}
}
\value{
  An integer vector with two elements:
  \item{width}{the number of pixels the window spans in the horizontal
    dimension}
  \item{height}{the number of pixels the window spans in the vertical dimension}  
}
\references{

}
\author{
Duncan Temple Lang <duncan@research.bell-labs.com>
}
\note{
}

\seealso{
\code{\link{gtkWidgetSetUsize}}
}

\examples{

}
\keyword{interface}


\eof
